@@ -130,7 +130,11 @@ InitErgmTerm.gwdsf <- function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
                       required = c(FALSE,FALSE,FALSE,FALSE,FALSE,FALSE))
   cl <- call("dgwdspL", decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type, alpha = a$alpha, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwdsf", a$type, "fixed", a$decay, sep = ".") else paste("gwdsf.fixed", a$decay, sep = ".")
+  trm$coef.names <- if (is.directed(nw)) {
+    paste("gwdsf", a$type, if (a$fixed) a$decay else NULL, sep = ".")
+  } else {
+    paste("gwdsf", if (a$fixed) a$decay else NULL, sep = ".")
+  }
   trm
 }
 
@@ -160,7 +164,11 @@ InitErgmTerm.gwdse <- function(nw, arglist,cache.sp=TRUE, gw.cutoff=30, ...) {
                       required = c(FALSE,FALSE,FALSE,FALSE,FALSE,FALSE))
   cl <- call("dgwdspL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type, alpha = a$alpha, Ls.path= c(~`-`,~`-`), L.in_order = a$in_order)
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwdse", a$type, "fixed", a$decay, sep = ".") else paste("gwdse.fixed", a$decay, sep = ".")
+  trm$coef.names <- if (is.directed(nw)) {
+    paste("gwdse", a$type, if (a$fixed) a$decay else NULL, sep = ".")
+  } else {
+    paste("gwdse", if (a$fixed) a$decay else NULL, sep = ".")
+  }
   trm
 }
 
@@ -171,6 +179,7 @@ InitErgmTerm.gwdse <- function(nw, arglist,cache.sp=TRUE, gw.cutoff=30, ...) {
 #' @usage
 #' # binary: esf(d, type="OTP", L.base=NULL, in_order=FALSE)
 #' @param d a vector of distinct integers
+#' @param lag logical; if TRUE, compute the lagged version of the esf statistic based on the previous time point's network
 #' @template ergmTerm-sp-type
 #' @template ergmTerm-L-base
 #'
@@ -182,20 +191,53 @@ InitErgmTerm.gwdse <- function(nw, arglist,cache.sp=TRUE, gw.cutoff=30, ...) {
 #' @concept undirected
 InitErgmTerm.esf <- function(nw, arglist, cache.sp=TRUE, ...) {
   a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("d","type","base", "in_order"),
-                      vartypes = c("numeric","character", "character,numeric","logical"),
-                      defaultvalues = list(NULL, "OTP", NULL, FALSE),
-                      required = c(TRUE, FALSE, FALSE, FALSE))
-  if (is.null(a$base)) {
-    b <- NULL
-  } else if (a$base %in% c("+", 1)) {
-    b <- ~`+`
-  } else if (a$base %in% c("-", -1)) {
-    b <- ~`-`
+                      varnames = c("d","type","base", "in_order", "lag"),
+                      vartypes = c("numeric","character", "character,numeric","logical", "logical"),
+                      defaultvalues = list(NULL, "OTP", NULL, FALSE, FALSE),
+                      required = c(TRUE, FALSE, FALSE, FALSE, FALSE))
+
+  if (!a$lag) {
+    if (is.null(a$base)) {
+      b <- NULL
+    } else if (a$base %in% c("+", 1)) {
+      b <- ~`+`
+    } else if (a$base %in% c("-", -1)) {
+      b <- ~`-`
+    }
+    cl <- call("despL", d = a$d, type = a$type, L.base = b, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
+  } else {
+    prev_net <- nw$gal$.PrevNets[[1]]
+    if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
+    if (is.null(prev_net)) stop("No previous network found")
+
+    # previous adjacency
+    prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "+")))
+
+    # shared partner matrix depending on directed type
+    sp <- switch(a$type,
+                 OTP = prev_adj %*% prev_adj,
+                 ITP = t(prev_adj) %*% t(prev_adj),
+                 RTP = (prev_adj * t(prev_adj) ) %*% (prev_adj * t(prev_adj)),
+                 OSP = t(prev_adj) %*% prev_adj,
+                 ISP = prev_adj %*% t(prev_adj)
+    )
+    diag(sp) <- 0
+
+    # current adjacency of requested base layer
+    n <- network.size(nw)
+    base_nodes <- which(nw %v% ".LayerName" == a$base)
+
+    # build delayed covariate matrix
+    tmp <- matrix(0, nrow = n, ncol = n)
+    if(!is.null(a$d)) sp[sp == a$d] <- 1
+    tmp[base_nodes, base_nodes] <- sp
+
+    # create edgecov term
+    cl <- call("edgecov", x = tmp)
   }
-  cl <- call("despL", d = a$d, type = a$type, L.base = b, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
+  lag_suffix <- if (isTRUE(a$lag)) ".lag" else ""
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("esf(",a$base,").", a$type, "#", a$d, sep = "") else paste("esf(",a$base, ")#", a$d,sep = "")
+  trm$coef.names <- if(is.directed(nw)) paste("esf(",a$base,").", a$type, "#", a$d,lag_suffix, sep = "") else paste("esf(",a$base, ")#", a$d,lag_suffix, sep = "")
   trm
 }
 
@@ -206,6 +248,7 @@ InitErgmTerm.esf <- function(nw, arglist, cache.sp=TRUE, ...) {
 #' @usage
 #' # binary: ese(d, type="OTP", L.base=NULL, in_order=FALSE)
 #' @param d a vector of distinct integers
+#' @param lag logical; if TRUE, compute the lagged version of the ese statistic based on the previous time point's network
 #' @template ergmTerm-sp-type
 #' @template ergmTerm-L-base
 #'
@@ -217,20 +260,53 @@ InitErgmTerm.esf <- function(nw, arglist, cache.sp=TRUE, ...) {
 #' @concept undirected
 InitErgmTerm.ese <- function(nw, arglist, cache.sp=TRUE, ...) {
   a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("d","type","base", "in_order"),
-                      vartypes = c("numeric","character", "character,numeric","logical"),
-                      defaultvalues = list(NULL, "OTP", NULL, FALSE),
-                      required = c(TRUE, FALSE, FALSE, FALSE))
-  if (is.null(a$base)) {
-    b <- NULL
-  } else if (a$base %in% c("+", 1)) {
-    b <- ~`+`
-  } else if (a$base %in% c("-", -1)) {
-    b <- ~`-`
+                      varnames = c("d","type","base", "in_order", "lag"),
+                      vartypes = c("numeric","character", "character,numeric","logical", "logical"),
+                      defaultvalues = list(NULL, "OTP", NULL, FALSE, FALSE),
+                      required = c(TRUE, FALSE, FALSE, FALSE, FALSE))
+
+  if(!a$lag) {
+    if (is.null(a$base)) {
+      b <- NULL
+    } else if (a$base %in% c("+", 1)) {
+      b <- ~`+`
+    } else if (a$base %in% c("-", -1)) {
+      b <- ~`-`
+    }
+    cl <- call("despL",d = a$d, type = a$type, L.base = b, Ls.path= c(~`-`,~`-`), L.in_order = a$in_order)
+  } else {
+    prev_net <- nw$gal$.PrevNets[[1]]
+    if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
+    if (is.null(prev_net)) stop("No previous network found")
+
+    # previous adjacency
+    prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "-")))
+
+    # shared partner matrix depending on directed type
+    sp <- switch(a$type,
+                 OTP = prev_adj %*% prev_adj,
+                 ITP = t(prev_adj) %*% t(prev_adj),
+                 RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
+                 OSP = t(prev_adj) %*% prev_adj,
+                 ISP = prev_adj %*% t(prev_adj)
+    )
+    diag(sp) <- 0
+
+    # current adjacency of requested base layer
+    n <- network.size(nw)
+    base_nodes <- which(nw %v% ".LayerName" == a$base)
+
+    # build delayed covariate matrix
+    tmp <- matrix(0, nrow = n, ncol = n)
+    if(!is.null(a$d)) sp[sp == a$d] <- 1
+    tmp[base_nodes, base_nodes] <- sp
+
+    # create edgecov term
+    cl <- call("edgecov", x = tmp)
   }
-  cl <- call("despL",d = a$d, type = a$type, L.base = b, Ls.path= c(~`-`,~`-`), L.in_order = a$in_order)
+  lag_suffix <- if (isTRUE(a$lag)) ".lag" else ""
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("ese(",a$base,").", a$type, "#", a$d, sep = "") else paste("ese(",a$base, ")#", a$d,sep = "")
+  trm$coef.names <- if(is.directed(nw)) paste("ese(",a$base,").", a$type, "#", a$d, lag_suffix, sep = "") else paste("ese(",a$base, ")#", a$d,lag_suffix, sep = "")
   trm
 }
 
@@ -242,6 +318,7 @@ InitErgmTerm.ese <- function(nw, arglist, cache.sp=TRUE, ...) {
 #' # binary: gwesf(decay, fixed=FALSE, cutoff=30, type="OTP", base=NULL, in_order=FALSE)
 #' @templateVar multiplicand shared friend or selected directed analogue count
 #' @template ergmTerm-gw-decay-fixed
+#' @param lag logical; if TRUE, compute the lagged version of the gwesf statistic based on the previous time point's network
 #' @templateVar underlying ESF
 #' @template ergmTerm-gw-cutoff
 #' @template ergmTerm-sp-type
@@ -255,20 +332,58 @@ InitErgmTerm.ese <- function(nw, arglist, cache.sp=TRUE, ...) {
 #' @concept undirected
 InitErgmTerm.gwesf <- function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
   a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("decay", "fixed", "cutoff","type","alpha","base","in_order"),
-                      vartypes = c("numeric","logical", "numeric","character","numeric", "character,numeric","logical"),
-                      defaultvalues = list(NULL,FALSE, gw.cutoff, "OTP", NULL,NULL, FALSE),
-                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE))
-  if (is.null(a$base)) {
-    b <- NULL
-  } else if (a$base %in% c("+", 1)) {
-    b <- ~`+`
-  } else if (a$base %in% c("-", -1)) {
-    b <- ~`-`
+                      varnames = c("decay", "fixed", "cutoff","type","alpha","base","in_order", "lag"),
+                      vartypes = c("numeric","logical", "numeric","character","numeric", "character,numeric","logical", "logical"),
+                      defaultvalues = list(NULL,FALSE, gw.cutoff, "OTP", NULL,NULL, FALSE, FALSE),
+                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE))
+
+
+  if (!a$lag) {
+    if (is.null(a$base)) {
+      b <- NULL
+    } else if (a$base %in% c("+", 1)) {
+      b <- ~`+`
+    } else if (a$base %in% c("-", -1)) {
+      b <- ~`-`
+    }
+    cl <- call("dgwespL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type, alpha = a$alpha, L.base = b, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
+  } else{
+    if (!a$fixed) stop("Curved exponential family models are not supported with lagged terms.")
+
+    prev_net <- nw$gal$.PrevNets[[1]]
+    if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
+    if (is.null(prev_net)) stop("No previous network found")
+
+    prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "+")))
+
+    sp <- switch(a$type,
+                 OTP = prev_adj %*% prev_adj,
+                 ITP = t(prev_adj) %*% t(prev_adj),
+                 RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
+                 OSP = t(prev_adj) %*% prev_adj,
+                 ISP = prev_adj %*% t(prev_adj)
+    )
+    diag(sp) <- 0
+
+    n <- network.size(nw)
+    base_nodes <- which(nw %v% ".LayerName" == a$base)
+
+    tmp <- matrix(0, nrow = n, ncol = n)
+
+    # Geometric weights: 1 - (1 - exp(-d))^sp
+    weights <-exp(a$decay)* (1 - (1 - exp(-a$decay))^sp)
+    tmp[base_nodes, base_nodes] <- weights
+
+    # create edgecov term with weighted shared partner covariate matrix
+    cl <- call("edgecov", x = tmp)
   }
-  cl <- call("dgwespL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type, alpha = a$alpha, L.base = b, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
+  lag_suffix <- if (isTRUE(a$lag)) ".lag" else ""
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwesf(",a$base,").", a$type, "fixed.", a$decay, sep = "") else paste("gwesf(",a$base, ").fixed.", a$decay,sep = "")
+  trm$coef.names <- if (is.directed(nw)) {
+    paste0("gwesf(", a$base, ").", a$type, if (a$fixed) paste0(".", a$decay) else "", lag_suffix)
+  } else {
+    paste0("gwesf(", a$base, ")", if (a$fixed) paste0(".", a$decay) else "", lag_suffix)
+  }
   trm
 }
 
@@ -280,6 +395,7 @@ InitErgmTerm.gwesf <- function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #' # binary: gwese(decay, fixed=FALSE, cutoff=30, type="OTP", base=NULL, in_order=FALSE)
 #' @templateVar multiplicand shared enemy or selected directed analogue count
 #' @template ergmTerm-gw-decay-fixed
+#' @param lag logical; if TRUE, compute the lagged version of the gwese statistic based on the previous time point's network
 #' @templateVar underlying ESE
 #' @template ergmTerm-gw-cutoff
 #' @template ergmTerm-sp-type
@@ -293,20 +409,61 @@ InitErgmTerm.gwesf <- function(nw, arglist, cache.sp=TRUE, gw.cutoff=30, ...) {
 #' @concept undirected
 InitErgmTerm.gwese <- function(nw, arglist, cache.sp=TRUE, gw.cutoff=30,...) {
   a <- check.ErgmTerm(nw, arglist,
-                      varnames = c("decay", "fixed", "cutoff","type","alpha","base","in_order"),
-                      vartypes = c("numeric","logical", "numeric","character","numeric", "character,numeric","logical"),
-                      defaultvalues = list(NULL,FALSE, gw.cutoff, "OTP", NULL,NULL, FALSE),
-                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE,FALSE, FALSE))
+                      varnames = c("decay", "fixed", "cutoff","type","alpha","base","in_order", "lag"),
+                      vartypes = c("numeric","logical", "numeric","character","numeric", "character,numeric","logical", "logical"),
+                      defaultvalues = list(NULL,FALSE, gw.cutoff, "OTP", NULL,NULL, FALSE, FALSE),
+                      required = c(FALSE, FALSE, FALSE, FALSE, FALSE,FALSE, FALSE, FALSE))
+  if (!a$lag) {
   if (is.null(a$base)) {
-    b <- NULL
-  } else if (a$base %in% c("+", 1)) {
-    b <- ~`+`
-  } else if (a$base %in% c("-", -1)) {
-    b <- ~`-`
+      b <- NULL
+    } else if (a$base %in% c("+", 1)) {
+      b <- ~`+`
+    } else if (a$base %in% c("-", -1)) {
+      b <- ~`-`
   }
   cl <- call("dgwespL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type,alpha = a$alpha, L.base = b, Ls.path= c(~`-`,~`-`), L.in_order = a$in_order)
+  } else {
+    if (!a$fixed) stop("Curved exponential family models are not supported with lagged terms.")
+
+    prev_net <- nw$gal$.PrevNets[[1]]
+    if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
+    if (is.null(prev_net)) stop("No previous network found")
+
+    # previous adjacency matrix for selected layer nodes
+    prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "-")))
+
+    # shared partner matrix depending on directed type
+    sp <- switch(a$type,
+                 OTP = prev_adj %*% prev_adj,
+                 ITP = t(prev_adj) %*% t(prev_adj),
+                 RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
+                 OSP = t(prev_adj) %*% prev_adj,
+                 ISP = prev_adj %*% t(prev_adj)
+    )
+    diag(sp) <- 0
+
+    # current adjacency of requested base layer
+    n <- network.size(nw)
+    base_nodes <- which(nw %v% ".LayerName" == a$base)
+
+    # Build geometrically weighted covariate matrix
+    tmp <- matrix(0, nrow = n, ncol = n)
+
+    # Geometric weights: 1 - (1 - exp(-d))^sp
+    weights <- exp(a$decay)* (1 - (1 - exp(-a$decay))^sp)
+    tmp[base_nodes, base_nodes] <- weights
+
+    # create edgecov term with weighted shared partner covariate matrix
+    cl <- call("edgecov", x = tmp)
+  }
+  lag_suffix <- if (isTRUE(a$lag)) ".lag" else ""
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwese(",a$base,").", a$type, "fixed.", a$decay, sep = "") else paste("gwese(",a$base, ").fixed.", a$decay,sep = "")
+  trm$coef.names <- if (is.directed(nw)) {
+    paste0("gwese(", a$base, ").", a$type, if (a$fixed) paste0(".", a$decay) else "", lag_suffix)
+  } else {
+    paste0("gwese(", a$base, ")", if (a$fixed) paste0(".", a$decay) else "", lag_suffix)
+  }
+
   trm
 }
 
@@ -414,7 +571,11 @@ InitErgmTerm.gwnsf <- function(nw, arglist,cache.sp=TRUE, gw.cutoff=30,...) {
   }
   cl <- call("dgwnspL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type,alpha = a$alpha, L.base = b, Ls.path= c(~`+`,~`+`), L.in_order = a$in_order)
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwnsf(",a$base,").", a$type, "fixed.", a$decay, sep = "") else paste("gwnsf(",a$base, ").fixed.", a$decay,sep = "")
+  trm$coef.names <- if (is.directed(nw)) {
+    paste0("gwnsf(", a$base, ").", a$type, if (a$fixed) paste0(".", a$decay) else "")
+  } else {
+    paste0("gwnsf(", a$base, ")", if (a$fixed) paste0(".", a$decay) else "")
+  }
   trm
 }
 
@@ -452,338 +613,11 @@ InitErgmTerm.gwnse <- function(nw, arglist,cache.sp=TRUE, gw.cutoff=30, ...) {
   }
   cl <- call("dgwnspL",decay = a$decay, fixed = a$fixed, cutoff = a$cutoff ,type = a$type,alpha = a$alpha, L.base = b, Ls.path= c(~`-`,~`-`), L.in_order = a$in_order)
   trm <- call.ErgmTerm(cl, nw, ...)
-  trm$coef.names <- if(is.directed(nw)) paste("gwnse(",a$base,").", a$type, "fixed.", a$decay, sep = "") else paste("gwnse(",a$base, ").fixed.", a$decay,sep = "")
-  trm
-}
-
-#' @templateVar name delese
-#' @title Delayed edgewise shared enemies
-#'
-#' @description
-#' This term adds one network statistic to the model that counts the number of
-#' positive or negative edges in the current network whose endpoints had exactly
-#' `d` shared enemies (common negative ties) in the previous network.
-#'
-#' For directed networks, different definitions of shared enemies can be specified
-#' using the `type` argument. For undirected networks, only one configuration applies.
-#'
-#' @usage
-#' # binary: delese(d = 1, base = "+", type = "OTP")
-#'
-#' @param d
-#' Integer.
-#' The exact number of shared enemies to count for edges in the current network.
-#'
-#' @param base
-#' Character indicating which edges in the current network are used as the base:
-#' `"+"` for positive ties or `"-"` for negative ties.
-#'
-#' @param type
-#' For directed networks, the definition of shared enemies:
-#' \describe{
-#'   \item{"OTP"}{Outgoing two-path (\( i -> k -> j \))}
-#'   \item{"ITP"}{Incoming two-path (\( j -> k -> i \))}
-#'   \item{"RTP"}{Reciprocated two-path (\( i <- k <- j \))}
-#'   \item{"OSP"}{Outgoing shared partner (\( i -> k, j -> k \))}
-#'   \item{"ISP"}{Incoming shared partner (\( k -> i, k -> j \))}
-#' }
-#' Ignored for undirected networks.
-#'
-#' @details
-#' For each edge in the current network (positive or negative, depending on `base`),
-#' this term checks how many nodes were connected negatively to both endpoints
-#' in the previous network.
-#'
-#' @concept delayed
-InitErgmTerm.delese <- function(nw, arglist, ...) {
-  a <- check.ErgmTerm(
-    nw, arglist,
-    varnames = c("d", "base", "type"),
-    vartypes = c("numeric", "character", "character"),
-    defaultvalues = list(NULL, NULL, "OTP"),
-    required = c(FALSE, TRUE, FALSE)
-  )
-
-  base <- match.arg(a$base, c("+", "-"))
-  d <- a$d
-  type <- match.arg(a$type, c("OTP", "ITP", "RTP", "OSP", "ISP"))
-  is_directed <- is.directed(nw)
-
-  # pick correct previous network
-  prev_net <- nw$gal$.PrevNets[[1]]
-  if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
-  if (is.null(prev_net)) stop("No previous network found")
-
-  # previous adjacency
-  prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "-")))
-
-  # shared partner matrix depending on directed type
-  sp <- switch(type,
-               OTP = prev_adj %*% prev_adj,
-               ITP = t(prev_adj) %*% t(prev_adj),
-               RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
-               OSP = t(prev_adj) %*% prev_adj,
-               ISP = prev_adj %*% t(prev_adj)
-  )
-  diag(sp) <- 0
-
-  # current adjacency of requested base layer
-  n <- network.size(nw)
-  base_nodes <- which(nw %v% ".LayerName" == base)
-
-  # build delayed covariate matrix
-  tmp <- matrix(0, nrow = n, ncol = n)
-  if(!is.null(d)) sp[sp == d] <- 1
-  tmp[base_nodes, base_nodes] <- sp
-
-  # create edgecov term
-  cl <- call("edgecov", x = tmp)
-  trm <- call.ErgmTerm(cl, nw, ...)
-
-  trm$coef.names <- paste0("delese", d, base, ifelse(is_directed, paste0("~", type), ""))
-  trm
-}
-
-
-#' @templateVar name delesf
-#' @title Delayed edgewise shared friends
-#'
-#' @description
-#' This term adds one network statistic to the model that counts the number of
-#' positive or negative edges in the current network whose endpoints had exactly
-#' `d` shared friends (common positive ties) in the previous network.
-#'
-#' For directed networks, different definitions of shared friends can be specified
-#' using the `type` argument. For undirected networks, only one configuration applies.
-#'
-#' @usage
-#' # binary: delese(d = 1, base = "+", type = "OTP")
-#'
-#' @param d
-#' Integer.
-#' The exact number of shared friends to count for edges in the current network.
-#'
-#' @param base
-#' Character indicating which edges in the current network are used as the base:
-#' `"+"` for positive ties or `"-"` for negative ties.
-#'
-#' @param type
-#' For directed networks, the definition of shared friends:
-#' \describe{
-#'   \item{"OTP"}{Outgoing two-path (\( i -> k -> j \))}
-#'   \item{"ITP"}{Incoming two-path (\( j -> k -> i \))}
-#'   \item{"RTP"}{Reciprocated two-path (\( i <- k <- j \))}
-#'   \item{"OSP"}{Outgoing shared partner (\( i -> k, j -> k \))}
-#'   \item{"ISP"}{Incoming shared partner (\( k -> i, k -> j \))}
-#' }
-#' Ignored for undirected networks.
-#'
-#' @details
-#' For each edge in the current network (positive or negative, depending on `base`),
-#' this term checks how many nodes were connected positively to both endpoints
-#' in the previous network.
-#'
-#' @concept delayed
-InitErgmTerm.delesf <- function(nw, arglist, ...) {
-  a <- check.ErgmTerm(
-    nw, arglist,
-    varnames = c("d", "base", "type"),
-    vartypes = c("numeric", "character", "character"),
-    defaultvalues = list(NULL, NULL, "OTP"),
-    required = c(FALSE, TRUE, FALSE)
-  )
-
-  base <- match.arg(a$base, c("+", "-"))
-  d <- a$d
-  type <- match.arg(a$type, c("OTP", "ITP", "RTP", "OSP", "ISP"))
-  is_directed <- is.directed(nw)
-  if (!is_directed && type != "OTP") {
-    warning("Undirected network: 'type' argument ignored")
-    type <- "OTP"
+  trm$coef.names <- if (is.directed(nw)) {
+    paste0("gwnse(", a$base, ").", a$type, if (a$fixed) paste0(".", a$decay) else "")
+  } else {
+    paste0("gwnse(", a$base, ")", if (a$fixed) paste0(".", a$decay) else "")
   }
-
-  # pick correct previous network
-  prev_net <- nw$gal$.PrevNets[[1]]
-  if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
-  if (is.null(prev_net)) stop("No previous network found")
-
-  # previous adjacency
-  prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "+")))
-
-  # shared partner matrix depending on directed type
-  sp <- switch(type,
-               OTP = prev_adj %*% prev_adj,
-               ITP = t(prev_adj) %*% t(prev_adj),
-               RTP = (prev_adj * t(prev_adj) ) %*% (prev_adj * t(prev_adj)),
-               OSP = t(prev_adj) %*% prev_adj,
-               ISP = prev_adj %*% t(prev_adj)
-  )
-  diag(sp) <- 0
-
-  # current adjacency of requested base layer
-  n <- network.size(nw)
-  base_nodes <- which(nw %v% ".LayerName" == base)
-
-  # build delayed covariate matrix
-  tmp <- matrix(0, nrow = n, ncol = n)
-  if(!is.null(d)) sp[sp == d] <- 1
-  tmp[base_nodes, base_nodes] <- sp
-
-  # create edgecov term
-  cl <- call("edgecov", x = tmp)
-  trm <- call.ErgmTerm(cl, nw, ...)
-
-  trm$coef.names <- paste0("delesf", d, base, ifelse(is_directed, paste0("~", type), ""))
-  trm
-}
-
-
-#' @templateVar name gwdelese
-#' @title Geometrically weighted delayed edgewise shared enemies
-#' @description This term calculates the number of shared enemies based on the previous network.
-#' It then applies a geometric transformation to these counts to reduce the influence of large counts.
-#' Specifically, if the decay parameter \code{decay} is provided, the weighting function used is
-#' \deqn{f(k; decay) = 1 - (1 - e^{-decay})^k,}{f(k; d) = 1 - (1 - exp(-decay))^k,}
-#' where \code{k} is the count of shared partners and \code{decay} controls how quickly the weight decreases as counts increase.
-#'
-#' @usage
-#' # binary: gwdelese(decay, base, type = "OTP")
-#'
-#' @param decay Numeric decay parameter controlling weighting intensity. If \code{NULL}, raw counts are used.
-#' @param base Character indicating which edges in the current network are used as the base:
-#' `"+"` for positive ties or `"-"` for negative ties.
-#' @param type Character specifying which shared partner pattern to use; one of
-#'   \code{"OTP"} (outgoing two-path),
-#'   \code{"ITP"} (incoming two-path),
-#'   \code{"RTP"} (reciprocated two-path),
-#'   \code{"OSP"} (outgoing shared partner),
-#'   \code{"ISP"} (incoming shared partner).
-#'
-#' @concept delayed
-InitErgmTerm.gwdelese <- function(nw, arglist, ...) {
-  a <- check.ErgmTerm(
-    nw, arglist,
-    varnames = c("decay", "base", "type"),
-    vartypes = c("numeric", "character", "character"),
-    defaultvalues = list(NULL, NULL, "OTP"),
-    required = c(TRUE, TRUE, FALSE)
-  )
-
-  base <- match.arg(a$base, c("+", "-"))
-  decay <- a$decay
-  type <- match.arg(a$type, c("OTP", "ITP", "RTP", "OSP", "ISP"))
-  is_directed <- is.directed(nw)
-
-  # pick correct previous network
-  prev_net <- nw$gal$.PrevNets[[1]]
-  if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
-  if (is.null(prev_net)) stop("No previous network found")
-
-  # previous adjacency matrix for selected layer nodes
-  prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "-")))
-
-  # shared partner matrix depending on directed type
-  sp <- switch(type,
-               OTP = prev_adj %*% prev_adj,
-               ITP = t(prev_adj) %*% t(prev_adj),
-               RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
-               OSP = t(prev_adj) %*% prev_adj,
-               ISP = prev_adj %*% t(prev_adj)
-  )
-  diag(sp) <- 0
-
-  # current adjacency of requested base layer
-  n <- network.size(nw)
-  base_nodes <- which(nw %v% ".LayerName" == base)
-
-  # Build geometrically weighted covariate matrix
-  tmp <- matrix(0, nrow = n, ncol = n)
-
-  # Geometric weights: 1 - (1 - exp(-d))^sp
-  weights <- exp(decay)* (1 - (1 - exp(-decay))^sp)
-  tmp[base_nodes, base_nodes] <- weights
-
-  # create edgecov term with weighted shared partner covariate matrix
-  cl <- call("edgecov", x = tmp)
-  trm <- call.ErgmTerm(cl, nw, ...)
-
-  trm$coef.names <- paste0("gwdelese", decay, base, ifelse(is_directed, paste0("~", type), ""))
-  trm
-}
-
-
-
-#' @templateVar name gwdelesf
-#' @title Geometrically weighted delayed edgewise shared friends
-#' @description This term calculates the number of shared friends based on the previous network.
-#' It then applies a geometric transformation to these counts to reduce the influence of large counts.
-#' Specifically, if the decay parameter \code{decay} is provided, the weighting function used is
-#' \deqn{f(k; decay) = 1 - (1 - e^{-decay})^k,}{f(k; decay) = 1 - (1 - exp(-d))^k,}
-#' where \code{k} is the count of shared partners and \code{decay} controls how quickly the weight decreases as counts increase.
-#' If \code{decay} is no
-#'
-#' @usage
-#' # binary: gwdelesf(decay, base, type = "OTP")
-#'
-#' @param decay Numeric decay parameter controlling weighting intensity. If \code{NULL}, raw counts are used.
-#' @param base Character indicating which edges in the current network are used as the base:
-#' `"+"` for positive ties or `"-"` for negative ties.
-#' @param type Character specifying which shared partner pattern to use; one of
-#'   \code{"OTP"} (outgoing two-path),
-#'   \code{"ITP"} (incoming two-path),
-#'   \code{"RTP"} (reciprocated two-path),
-#'   \code{"OSP"} (outgoing shared partner),
-#'   \code{"ISP"} (incoming shared partner).
-#'
-#' @concept delayed
-InitErgmTerm.gwdelesf <- function(nw, arglist, gw.cutoff=30, ...) {
-  a <- check.ErgmTerm(
-    nw, arglist,
-    varnames = c("decay", "base", "type"),
-    vartypes = c("numeric", "character", "character"),
-    defaultvalues = list(NULL, NULL, "OTP"),
-    required = c(TRUE, TRUE, FALSE)
-  )
-
-  base <- match.arg(a$base, c("+", "-"))
-  decay <- a$decay
-  type <- match.arg(a$type, c("OTP", "ITP", "RTP", "OSP", "ISP"))
-  is_directed <- is.directed(nw)
-
-  # pick correct previous network
-  prev_net <- nw$gal$.PrevNets[[1]]
-  if (is.null(prev_net)) prev_net <- nw$gal$.PrevNet
-  if (is.null(prev_net)) stop("No previous network found")
-
-  # previous adjacency matrix for selected layer nodes
-  prev_adj <- as.matrix(get.inducedSubgraph(prev_net, which(prev_net %v% ".LayerName" == "+")))
-
-  # shared partner matrix depending on directed type
-  sp <- switch(type,
-               OTP = prev_adj %*% prev_adj,
-               ITP = t(prev_adj) %*% t(prev_adj),
-               RTP = (prev_adj * t(prev_adj)) %*% (prev_adj * t(prev_adj)),
-               OSP = t(prev_adj) %*% prev_adj,
-               ISP = prev_adj %*% t(prev_adj)
-  )
-  diag(sp) <- 0
-
-  # current adjacency of requested base layer
-  n <- network.size(nw)
-  base_nodes <- which(nw %v% ".LayerName" == base)
-
-  # Build geometrically weighted covariate matrix
-  tmp <- matrix(0, nrow = n, ncol = n)
-
-  # Geometric weights: 1 - (1 - exp(-d))^sp
-  weights <-exp(decay)* (1 - (1 - exp(-decay))^sp)
-  tmp[base_nodes, base_nodes] <- weights
-
-  # create edgecov term with weighted shared partner covariate matrix
-  cl <- call("edgecov", x = tmp)
-  trm <- call.ErgmTerm(cl, nw, ...)
-
-  trm$coef.names <- paste0("gwdelesf", decay, base, ifelse(is_directed, paste0("~", type), ""))
   trm
 }
 
